summary refs log tree commit diff
path: root/gen/ANFVisitor.py
diff options
context:
space:
mode:
Diffstat (limited to 'gen/ANFVisitor.py')
-rw-r--r--gen/ANFVisitor.py52
1 files changed, 46 insertions, 6 deletions
diff --git a/gen/ANFVisitor.py b/gen/ANFVisitor.py
index 982fa58..e1bf0b4 100644
--- a/gen/ANFVisitor.py
+++ b/gen/ANFVisitor.py
@@ -9,18 +9,58 @@ else:
 
 class ANFVisitor(ParseTreeVisitor):
 
-    # Visit a parse tree produced by ANFParser#aexp.
-    def visitAexp(self, ctx:ANFParser.AexpContext):
+    # Visit a parse tree produced by ANFParser#var.
+    def visitVar(self, ctx:ANFParser.VarContext):
         return self.visitChildren(ctx)
 
 
-    # Visit a parse tree produced by ANFParser#funcall.
-    def visitFuncall(self, ctx:ANFParser.FuncallContext):
+    # Visit a parse tree produced by ANFParser#num.
+    def visitNum(self, ctx:ANFParser.NumContext):
         return self.visitChildren(ctx)
 
 
-    # Visit a parse tree produced by ANFParser#cexp.
-    def visitCexp(self, ctx:ANFParser.CexpContext):
+    # Visit a parse tree produced by ANFParser#add.
+    def visitAdd(self, ctx:ANFParser.AddContext):
+        return self.visitChildren(ctx)
+
+
+    # Visit a parse tree produced by ANFParser#sub.
+    def visitSub(self, ctx:ANFParser.SubContext):
+        return self.visitChildren(ctx)
+
+
+    # Visit a parse tree produced by ANFParser#mul.
+    def visitMul(self, ctx:ANFParser.MulContext):
+        return self.visitChildren(ctx)
+
+
+    # Visit a parse tree produced by ANFParser#div.
+    def visitDiv(self, ctx:ANFParser.DivContext):
+        return self.visitChildren(ctx)
+
+
+    # Visit a parse tree produced by ANFParser#lam.
+    def visitLam(self, ctx:ANFParser.LamContext):
+        return self.visitChildren(ctx)
+
+
+    # Visit a parse tree produced by ANFParser#call.
+    def visitCall(self, ctx:ANFParser.CallContext):
+        return self.visitChildren(ctx)
+
+
+    # Visit a parse tree produced by ANFParser#atom.
+    def visitAtom(self, ctx:ANFParser.AtomContext):
+        return self.visitChildren(ctx)
+
+
+    # Visit a parse tree produced by ANFParser#let.
+    def visitLet(self, ctx:ANFParser.LetContext):
+        return self.visitChildren(ctx)
+
+
+    # Visit a parse tree produced by ANFParser#fc.
+    def visitFc(self, ctx:ANFParser.FcContext):
         return self.visitChildren(ctx)